@@ -43,7 +43,7 @@ impl Core {
                 msg: Box::new(msg),
                 dest_info: received_dest_info,
             },
-            None,
+            self.section.authority_provider().section_key,
         )?;
 
         let cmd = if let Some(sender) = sender {
@@ -59,7 +59,7 @@ impl Core {
         &self,
         sender: Peer,
         dst_key: bls::PublicKey,
-        bounced_msg: RoutingMsg,
+        mut bounced_msg: RoutingMsg,
     ) -> Result<Command> {
         let span = trace_span!("Received BouncedUntrustedMessage", ?bounced_msg, %sender);
         let _span_guard = span.enter();
@@ -81,15 +81,13 @@ impl Core {
                     &self.node,
                     DstLocation::DirectAndUnrouted,
                     Variant::Sync { section, network },
-                    None,
+                    self.section.authority_provider().section_key,
                 )?
             }
-            _ => bounced_msg
-                .extend_proof_chain(&dst_key, self.section.chain())
-                .map_err(|err| {
-                    error!("extending proof chain failed: {:?}", err);
-                    Error::InvalidMessage // TODO: more specific error
-                })?,
+            _ => {
+                bounced_msg.updated_with_latest_key(self.section.authority_provider().section_key);
+                bounced_msg
+            }
         };
 
         let dest_info = DestInfo {
